@@ -2,7 +2,7 @@
 
 /*
  * 饯ɲ
- * $Id: addchar.php,v 1.15 2003/01/12 16:56:17 yuryu Exp $
+ * $Id: addchar.php,v 1.16 2003/01/25 05:21:26 yuryu Exp $
  *
  */
 
@@ -165,11 +165,11 @@ function show_entryform($request)
 	if(! GUILD_SPEC){
 		print("<dt></dt><dd><select name='guild'>\n");
 		global $guild_list;
-		foreach($guild_list as $guild){
+		foreach($guild_list as $guild => $guilddata){
 			if($guild == $request['guild']){
-				printf("<option selected='selected'>%s</option>\n", $guild);
+				printf("<option selected='selected' value='%s'>%s</option>\n", $guild, $guilddata['Name']);
 			}else{
-				printf("<option>%s</option>\n", $guild);
+				printf("<option value='%s'>%s</option>\n", $guild, $guilddata['Name']);
 			}
 		}
 		print("</select></dd>\n");
