@@ -2,7 +2,7 @@
 
 /*
  * clist xml ǡ륹ץ
- * $Id: updateall.php,v 1.1 2003/01/08 18:59:11 yuryu Exp $
+ * $Id: updateall.php,v 1.2 2003/01/25 05:21:26 yuryu Exp $
  */
 
 require_once("./settings.php");
@@ -10,10 +10,10 @@ require_once("./readxmls.php");
 
 header("Content-Type: text/plain");
 
-foreach($guild_xmls as $guild_xml)
+foreach($guild_list as $guild)
 {
-	echo "Parsing $guild_xml ...";
-	parse_xml($guild_xml);
+	echo "Parsing " . $guild['Xml'] . " ...";
+	parse_xml($guild['Xml']);
 	echo " done\n";
 }
 
